# wagner_dio_image_processing

Description. 
The package wagner_dio_image_processing is used to:
	Processing:
	- Histogram matching
	- Structural smilarity
	- Resize image
	Utils:
	- Read image
	- Save image
	- Plot image
	- Plot result
	- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install wagner_dio_image_processing
```

## Author
Wagner_Trindade

## License
[MIT](https://choosealicense.com/licenses/mit/)